# Layouts

These examples show the different layouts that can be implemented through Dashport.


## split_screen_columns

![split_screen_vert for dashport](../images/Layout_split_screen_vert.png)


## split_screen_rows

![split_screen_horizontal for dashport](../images/Layout_split_screen_horizontal.png)


## quadrants

![quadrants for dashport](../images/Layout_quadrants.png)

## three_panels_horizontal

![three_way horizontal for dashport](../images/Layout_three_horizontal.png)

## three_panels_vertical

![three_way vert for dashport](../images/Layout_three_vert.png)
